from __future__ import annotations

from koldstart.api import KoldstartHost, LocalHost, cached, isolated
from koldstart.sdk import CloudKeyCredentials

local = LocalHost()
cloud = KoldstartHost()
